<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="uk_UA">
<context>
    <name>@default</name>
    <message>
        <location filename="../src/main.cpp" line="82"/>
        <source>File does not exist</source>
        <translation type="unfinished">Файла не існує</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="86"/>
        <source>The file %1 could not be found. Please check this and try again.</source>
        <translation type="unfinished">Файл %1 неможливо знайти. Будь ласка, перевірте його наявніть і спробуйте ще раз.</translation>
    </message>
</context>
<context>
    <name>QDialog</name>
    <message>
        <location filename="../src/dialogs.cpp" line="81"/>
        <source>Program Files</source>
        <translation type="obsolete">Program Files</translation>
    </message>
</context>
<context>
    <name>pageFinished</name>
    <message>
        <location filename="../dialogs/page_setup_finished.ui" line="43"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;iTALC is now installed!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;iTALC встановлено!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_setup_finished.ui" line="61"/>
        <source>iTALC is now completely installed. If you installed the master application you can start it using the start-menu.</source>
        <translation>Тепер iTALC повністю встановлено. Якщо Ви встановили головну програму, Ви можете запустити її з меню &quot;Пуск&quot;.</translation>
    </message>
    <message>
        <location filename="../dialogs/page_setup_finished.ui" line="71"/>
        <source>Save installation settings</source>
        <translation>Зберегти параметри встановлення</translation>
    </message>
</context>
<context>
    <name>pageInstallDir</name>
    <message>
        <location filename="../dialogs/page_install_dir.ui" line="37"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Choose installation directory&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Оберіть теку для встановлення&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_install_dir.ui" line="47"/>
        <source>Please choose the directory in which iTALC is going to be installed. It&apos;s recommended to leave the default-directory, but it&apos;s no problem to change it.</source>
        <translation>Будь ласка, оберіть теку, до якої слід встановити iTALC. Рекомендується залишити типову теку, але і її зміна не буде проблемою.</translation>
    </message>
</context>
<context>
    <name>pageKeyDirs</name>
    <message>
        <location filename="../dialogs/page_key_dirs.ui" line="37"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Directories for keys&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Теки для ключів&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_key_dirs.ui" line="47"/>
        <source>The newly created or imported key(s) need to be installed somewhere. It&apos;s recommended to leave the suggested directories.</source>
        <translation>Створені або імпортовані ключі слід десь зберігати. Рекомендується залишити запропоновані теки без змін.</translation>
    </message>
    <message>
        <location filename="../dialogs/page_key_dirs.ui" line="73"/>
        <source>Directory to store public key in</source>
        <translation>Тека для зберігання публічного ключа</translation>
    </message>
    <message>
        <location filename="../dialogs/page_key_dirs.ui" line="147"/>
        <source>Directory to store private key in</source>
        <translation>Тека для зберігання особистого ключа</translation>
    </message>
    <message>
        <location filename="../dialogs/page_key_dirs.ui" line="212"/>
        <source>You can choose a directory in which to export the public key, e.g. a USB-drive or a network share.</source>
        <translation>Ви можете обрати теку, до якої слід експортувати пулічний ключ, наприклад, флеш-карту або спільну мережеву теку.</translation>
    </message>
    <message>
        <location filename="../dialogs/page_key_dirs.ui" line="258"/>
        <source>Export private key too</source>
        <translation>Експортувати також особистий ключ</translation>
    </message>
</context>
<context>
    <name>pageLicenseAgreement</name>
    <message>
        <location filename="../dialogs/page_license_agreement.ui" line="40"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;License agreement&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Ліцензійна угода&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_license_agreement.ui" line="50"/>
        <source>iTALC is published under the terms of the General Public License (GPL). Please read the following license terms and choose whether you agree or disagree the license.</source>
        <translation>iTALC поширюється за умов дотримання General Public License (GPL). Будь ласка прочитайте розміщені нижче пункти угоди і виберіть чи погоджуєтеся Ви з ними.</translation>
    </message>
    <message>
        <location filename="../dialogs/page_license_agreement.ui" line="81"/>
        <source>I agree</source>
        <translation>Я згоден(на)</translation>
    </message>
    <message>
        <location filename="../dialogs/page_license_agreement.ui" line="88"/>
        <source>I disagree</source>
        <translation>Я не згоден(на)</translation>
    </message>
</context>
<context>
    <name>pageSecurityOptions</name>
    <message>
        <location filename="../dialogs/page_security_options.ui" line="53"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Security options&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Параметри безпеки&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_security_options.ui" line="63"/>
        <source>iTALC has a sophisticated security-concept for preventing unauthorized access to computers having iTALC client software installed. Therefore you either have to create a new key-pair or import the public key created during iTALC installation on master computer.</source>
        <translation>iTALC має складну концепцію забезпечення захисту від неавторизованого доступу до комп’ютерів з встановленим клієнтом iTALC. Тому Вам слід або створити нову пару ключів, або імпортувати публічний ключ, створений під час встановлення iTALC на головному комп’ютері.</translation>
    </message>
    <message>
        <location filename="../dialogs/page_security_options.ui" line="73"/>
        <source>Create a new key-pair (only do that on master computer)</source>
        <translation>Створити нову пару ключів (робіть це лише на головному комп’ютері)</translation>
    </message>
    <message>
        <location filename="../dialogs/page_security_options.ui" line="80"/>
        <source>Import public key of master computer</source>
        <translation>Імпортувати публічний ключ головного комп’ютера</translation>
    </message>
    <message>
        <location filename="../dialogs/page_security_options.ui" line="114"/>
        <source>Choose location of exported public key:</source>
        <translation>Оберіть розташування експортованого публічного ключа:</translation>
    </message>
    <message>
        <location filename="../dialogs/page_security_options.ui" line="152"/>
        <source>Keep all keys (only when updating existing installation!)</source>
        <translation>Зберегти всі ключі (тільки якщо Ви оновлюєте програму!)</translation>
    </message>
</context>
<context>
    <name>pageSelectComponents</name>
    <message>
        <location filename="../dialogs/page_select_components.ui" line="37"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Select components to install&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Оберіть компоненти для встановлення&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_select_components.ui" line="55"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Now it&apos;s time to choose which components of iTALC you want to install on this computer. If this is a client-computer you should only install the client-software.&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600; font-style:italic;&quot;&gt;Please note, that the master application depends the client-software in order to function properly.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Настав час обрати компоненти iTALC, які Ви бажаєте встановити на цей комп’ютер. Якщо це комп’ютер-клієнт, Вам слід встановити лише клієнтську програму.&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600; font-style:italic;&quot;&gt;Будь ласка, азуважте, що головна програма залежить від клієнтської програми і без неї не працюватиме.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_select_components.ui" line="70"/>
        <source>Components</source>
        <translation>Компоненти</translation>
    </message>
    <message>
        <location filename="../dialogs/page_select_components.ui" line="93"/>
        <source>iTALC Client Appliction (ICA)</source>
        <translation>Клієнтська програма iTALC (ICA)</translation>
    </message>
    <message>
        <location filename="../dialogs/page_select_components.ui" line="103"/>
        <source>iTALC Master Application (IMA)</source>
        <translation>Головна програма iTALC (IMA)</translation>
    </message>
    <message>
        <location filename="../dialogs/page_select_components.ui" line="113"/>
        <source>Online-Update Service (LUPUS)</source>
        <translation>Служба мережевого оновлення (LUPUS)</translation>
    </message>
    <message>
        <location filename="../dialogs/page_select_components.ui" line="123"/>
        <source>iTALC documentation</source>
        <translation>Документація iTALC</translation>
    </message>
</context>
<context>
    <name>pageWelcome</name>
    <message>
        <location filename="../dialogs/page_welcome.ui" line="43"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Welcome to installation of iTALC&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:13pt; font-weight:600;&quot;&gt;Ласкаво просимо до програми з встановлення iTALC&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogs/page_welcome.ui" line="61"/>
        <source>This setup-wizard will guide you through the installation of iTALC on this computer. The installation includes the client-software as well as the optional master-application.

Furthermore you&apos;ll be able to setup security-settings.

Click &apos;Next&apos; to continue.</source>
        <translation>Цей майстер допоможе Вам встановити iTALC на цей комп’ютер. Пакет містить у собі клієнтську програму і додаткову головну програму.

Крім того, Ви зможете встановити параметри безпеки.

Натисніть &apos;Далі&apos;, щоб продовжити.</translation>
    </message>
</context>
<context>
    <name>setupWizard</name>
    <message>
        <location filename="../src/dialogs.cpp" line="155"/>
        <source>Confirm overwrite</source>
        <translation>Підтвердження перезапису</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="156"/>
        <source>Do you want to overwrite %1?</source>
        <translation>Ви бажаєте перезаписати %1?</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="212"/>
        <source>Installing iTALC</source>
        <translation>Встановлення iTALC</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="214"/>
        <source>Copying files...</source>
        <translation>Копіювання файлів...</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="279"/>
        <source>Registering ICA as service...</source>
        <translation>Реєстрація служби ICA...</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="322"/>
        <source>Creating/importing keys...</source>
        <translation>Створення/імпорт ключів...</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="354"/>
        <source>Creating shortcuts...</source>
        <translation>Створення посилань...</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="376"/>
        <source>Could not create directory</source>
        <translation>Не вдалося створити теку</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="380"/>
        <source>Could not create directory %1! Make sure you have the neccessary rights and try again!</source>
        <translation>Не вдалося створити теку %1! Переконайтеся, що Ви маєте на це дозвіл і спробуйте ще раз!</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="393"/>
        <source>Cancel setup</source>
        <translation>Скасувати встановлення</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="395"/>
        <source>Are you sure want to quit setup? iTALC is not installed completely yet!</source>
        <translation>Ви справді бажаєте вийти з програми встановлення? iTALC ще не встановлено повністю!</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="416"/>
        <source>Next</source>
        <translation>Далі</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="475"/>
        <source>Finish</source>
        <translation>Завершити</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="481"/>
        <source>Quit</source>
        <translation>Вийти</translation>
    </message>
</context>
<context>
    <name>setupWizardPageInstallDir</name>
    <message>
        <location filename="../src/dialogs.cpp" line="590"/>
        <source>Directory does not exist</source>
        <translation>Теки не існує</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="592"/>
        <source>The specified directory does not exist. Do you want to create it?</source>
        <translation>Заданої теки не існує. Ви бажаєте її створити?</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="614"/>
        <source>Choose installation directory</source>
        <translation>Вибір теки встановлення</translation>
    </message>
</context>
<context>
    <name>setupWizardPageKeyDirs</name>
    <message>
        <location filename="../src/dialogs.cpp" line="848"/>
        <source>Choose public key directory</source>
        <translation>Вибір теки публічного ключа</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="862"/>
        <source>Choose private key directory</source>
        <translation>Вибір теки особистого ключа</translation>
    </message>
    <message>
        <location filename="../src/dialogs.cpp" line="876"/>
        <source>Choose public key export directory</source>
        <translation>Вибір теки експорту публічного ключа</translation>
    </message>
</context>
<context>
    <name>setupWizardPageSecurityOptions</name>
    <message>
        <location filename="../src/dialogs.cpp" line="750"/>
        <source>Choose directory for key-import</source>
        <translation>Вибір теки імпорту ключа</translation>
    </message>
</context>
<context>
    <name>wizard</name>
    <message>
        <location filename="../dialogs/wizard.ui" line="21"/>
        <source>iTALC-Setup</source>
        <translation>Програма з встановлення iTALC</translation>
    </message>
    <message>
        <location filename="../dialogs/wizard.ui" line="67"/>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <location filename="../dialogs/wizard.ui" line="77"/>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <location filename="../dialogs/wizard.ui" line="87"/>
        <source>Next</source>
        <translation>Далі</translation>
    </message>
</context>
</TS>
